@@ -5,12 +5,13 @@ import requests
 from maitai._config_listener_thread import ConfigListenerThread
 from maitai_common.config import config_service
 from maitai_gen.application import Application
+from maitai_gen.chat import ChatCompletionAuth
 from maitai_gen.config import Config as ActionConfig
 
 
 class Config:
     maitai_host = os.environ.get("MAITAI_HOST", 'https://api.trymaitai.ai')
-    maitai_ws = os.environ.get("MAITAI_WS", 'wss://humrvommw4.execute-api.us-west-2.amazonaws.com/production')
+    maitai_ws = os.environ.get("MAITAI_WS", 'wss://09hidyy627.execute-api.us-west-2.amazonaws.com/production')
 
     def __init__(self):
         self._api_key = None
@@ -19,11 +20,19 @@ class Config:
         self.websocket_listener_thread = None
         self.config_listener_thread = None
         self._application_action_configs: dict[str, dict[str, ActionConfig]] = {}
+        self.initialized = False
+        self.auth_info = ChatCompletionAuth(
+            openai_api_key=os.environ.get("OPENAI_API_KEY"),
+            groq_api_key=os.environ.get("GROQ_API_KEY"),
+        )
 
     @property
     def api_key(self):
         if self._api_key is None:
-            raise ValueError("Maitai API Key has not been set")
+            if self.initialized:
+                raise ValueError("Maitai API Key has not been set")
+            else:
+                self.initialize(api_key=os.environ.get("MAITAI_API_KEY"))
         return self._api_key
 
     @api_key.setter
@@ -35,6 +44,7 @@ class Config:
         self._initialize_company()
         self.refresh_applications()
         self._initialize_websocket()
+        self.initialized = True
 
     def get_application(self, application_ref_name: str) -> Application:
         return self._applications.get(application_ref_name)
